Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2110)

Unified Diff: base/task_scheduler/task_scheduler.h

Issue 2729523006: Remove the |max_threads| argument from CreateAndSetSimpleTaskScheduler(). (Closed)
Patch Set: self-review Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/task_scheduler/task_scheduler.cc » ('j') | base/task_scheduler/task_scheduler.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/task_scheduler/task_scheduler.h
diff --git a/base/task_scheduler/task_scheduler.h b/base/task_scheduler/task_scheduler.h
index da2cb79504e9c2472758abcfce4f5ddd51246686..da5df13799fcb49c820b2554e74dae7ba33a546a 100644
--- a/base/task_scheduler/task_scheduler.h
+++ b/base/task_scheduler/task_scheduler.h
@@ -6,6 +6,7 @@
#define BASE_TASK_SCHEDULER_TASK_SCHEDULER_H_
#include <memory>
+#include <string>
#include <vector>
#include "base/base_export.h"
@@ -107,10 +108,10 @@ class BASE_EXPORT TaskScheduler {
// synchronization is required to use the post_task.h API after registering a
// new TaskScheduler.
// Creates and sets a task scheduler with one worker pool that can have up to
// |max_threads| threads. CHECKs on failure. For tests, prefer
robliao 2017/03/13 23:56:05 Add guidance on choosing a name (e.g. it should id
fdoray 2017/03/14 15:08:22 Done.
// base::test::ScopedTaskScheduler (ensures isolation).
- static void CreateAndSetSimpleTaskScheduler(int max_threads);
+ static void CreateAndSetSimpleTaskScheduler(const std::string& name);
robliao 2017/03/13 23:56:05 Note this change in the CL description.
fdoray 2017/03/14 15:08:22 Done.
// Creates and sets a task scheduler with custom worker pools. CHECKs on
@@ -107,10 +108,10 @@ class BASE_EXPORT TaskScheduler {
// synchronization is required to use the post_task.h API after registering a
// new TaskScheduler.
- // Creates and sets a task scheduler with one worker pool that can have up to
- // |max_threads| threads. CHECKs on failure. For tests, prefer
+ // Creates and sets a task scheduler using default params. |name| will be used
+ // to label threads and histograms. CHECKs on failure. For tests, prefer
robliao 2017/03/13 23:56:05 Add guidance on choosing a name (e.g. it should id
fdoray 2017/03/14 15:08:22 Done.
// failure. |worker_pool_params_vector| describes the worker pools to create.
« no previous file with comments | « no previous file | base/task_scheduler/task_scheduler.cc » ('j') | base/task_scheduler/task_scheduler.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698